documentationtools.AbjadAPIGenerator
====================================

.. abjad-lineage:: abjad.tools.documentationtools.AbjadAPIGenerator.AbjadAPIGenerator

.. autoclass:: abjad.tools.documentationtools.AbjadAPIGenerator.AbjadAPIGenerator

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.documentationtools.AbjadAPIGenerator.AbjadAPIGenerator.docs_api_index_path
      ~abjad.tools.documentationtools.AbjadAPIGenerator.AbjadAPIGenerator.package_prefix
      ~abjad.tools.documentationtools.AbjadAPIGenerator.AbjadAPIGenerator.path_definitions
      ~abjad.tools.documentationtools.AbjadAPIGenerator.AbjadAPIGenerator.root_package
      ~abjad.tools.documentationtools.AbjadAPIGenerator.AbjadAPIGenerator.tools_package_path_index
      ~abjad.tools.documentationtools.AbjadAPIGenerator.AbjadAPIGenerator.__call__
      ~abjad.tools.documentationtools.AbjadAPIGenerator.AbjadAPIGenerator.__eq__
      ~abjad.tools.documentationtools.AbjadAPIGenerator.AbjadAPIGenerator.__format__
      ~abjad.tools.documentationtools.AbjadAPIGenerator.AbjadAPIGenerator.__hash__
      ~abjad.tools.documentationtools.AbjadAPIGenerator.AbjadAPIGenerator.__ne__
      ~abjad.tools.documentationtools.AbjadAPIGenerator.AbjadAPIGenerator.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.AbjadAPIGenerator.AbjadAPIGenerator.docs_api_index_path
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.AbjadAPIGenerator.AbjadAPIGenerator.package_prefix
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.AbjadAPIGenerator.AbjadAPIGenerator.path_definitions
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.AbjadAPIGenerator.AbjadAPIGenerator.root_package
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.AbjadAPIGenerator.AbjadAPIGenerator.tools_package_path_index
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.documentationtools.AbjadAPIGenerator.AbjadAPIGenerator.__call__
   :noindex:

.. automethod:: abjad.tools.documentationtools.AbjadAPIGenerator.AbjadAPIGenerator.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.AbjadAPIGenerator.AbjadAPIGenerator.__format__
   :noindex:

.. automethod:: abjad.tools.documentationtools.AbjadAPIGenerator.AbjadAPIGenerator.__hash__
   :noindex:

.. automethod:: abjad.tools.documentationtools.AbjadAPIGenerator.AbjadAPIGenerator.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.AbjadAPIGenerator.AbjadAPIGenerator.__repr__
   :noindex:
